==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSelectItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebSelectItemDescription } from "./WebSelectItemDescription";
/**
 * @hidden
 */
var WebSelectItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSelectItemDescriptionMetadata, _super);
    function WebSelectItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectItemDescriptionMetadata.b = function (a) {
        if (WebSelectItemDescriptionMetadata.a == null) {
            WebSelectItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectItemDescriptionMetadata.c(WebSelectItemDescriptionMetadata.a);
        }
        if (a.k(WebSelectItemDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSelectItemDescriptionMetadata.a);
    };
    WebSelectItemDescriptionMetadata.c = function (a) {
        WebDropdownItemDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:SelectItem");
        a.item("__tagNameWC", "String:igc-select-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("TextContent", "String");
    };
    WebSelectItemDescriptionMetadata.d = function (a) {
        WebSelectItemDescriptionMetadata.b(a);
        a.ac("WebSelectItem", function () { return new WebSelectItemDescription(); });
        a.ab("WebSelectItem", WebSelectItemDescriptionMetadata.a);
    };
    WebSelectItemDescriptionMetadata.$t = markType(WebSelectItemDescriptionMetadata, 'WebSelectItemDescriptionMetadata');
    WebSelectItemDescriptionMetadata.a = null;
    return WebSelectItemDescriptionMetadata;
}(Base));
export { WebSelectItemDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSelectItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseOptionLikeDescriptionMetadata } from "./WebBaseOptionLikeDescriptionMetadata";
import { WebSelectItemDescription } from "./WebSelectItemDescription";
/**
 * @hidden
 */
var WebSelectItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectItemDescriptionMetadata, _super);
    function WebSelectItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectItemDescriptionMetadata.b = function (a) {
        if (WebSelectItemDescriptionMetadata.a == null) {
            WebSelectItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectItemDescriptionMetadata.c(WebSelectItemDescriptionMetadata.a);
        }
        if (a.k(WebSelectItemDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSelectItemDescriptionMetadata.a);
    };
    WebSelectItemDescriptionMetadata.c = function (a) {
        WebBaseOptionLikeDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:SelectItem");
        a.item("__tagNameWC", "String:igc-select-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebSelectItemDescriptionMetadata.d = function (a) {
        WebSelectItemDescriptionMetadata.b(a);
        a.ae("WebSelectItem", function () { return new WebSelectItemDescription(); });
        a.ad("WebSelectItem", WebSelectItemDescriptionMetadata.a);
    };
    WebSelectItemDescriptionMetadata.$t = markType(WebSelectItemDescriptionMetadata, 'WebSelectItemDescriptionMetadata');
    WebSelectItemDescriptionMetadata.a = null;
    return WebSelectItemDescriptionMetadata;
}(Base));
export { WebSelectItemDescriptionMetadata };
